@@ -7,13 +7,16 @@
 #include <string.h>
 #include <stdarg.h>
 #include "Charmonizer/Probe.h"
-#include "Charmonizer/Probe/DirSep.h"
+#include "Charmonizer/Probe/DirManip.h"
+#include "Charmonizer/Probe/Floats.h"
 #include "Charmonizer/Probe/FuncMacro.h"
 #include "Charmonizer/Probe/Headers.h"
 #include "Charmonizer/Probe/Integers.h"
 #include "Charmonizer/Probe/LargeFiles.h"
 #include "Charmonizer/Probe/UnusedVars.h"
 #include "Charmonizer/Probe/VariadicMacros.h"
+#include "Charmonizer/Core/HeadCheck.h"
+#include "Charmonizer/Core/ModHandler.h"
 
 char *cc_command, *cc_flags, *os_name, *verbosity_str;
 
@@ -49,10 +52,11 @@ int main(int argc, char **argv)
     init(argc, argv);
 
     /* modules section */
-    chaz_DirSep_run();
+    chaz_DirManip_run();
     chaz_Headers_run();
     chaz_FuncMacro_run();
     chaz_Integers_run();
+    chaz_Floats_run();
     chaz_LargeFiles_run();
     chaz_UnusedVars_run();
     chaz_VariadicMacros_run();
@@ -151,14 +155,8 @@ extract_delim_and_verify(char *source, size_t source_len, const char *tag_name)
 static void
 write_charmony_postamble(void)
 {
-    FILE *charmony_fh = chaz_Probe_get_charmony_fh();
-
-    if (strcmp(os_name, "mswin32") == 0) {
-        fprintf(charmony_fh,
-            "#ifndef KINO_HAS_LARGE_FILE_SUPPORT\n"
-            "  #include \"win32lfs.h\"\n"  
-            "#endif /* KINO_HAS_LARGE_FILE_SUPPORT */\n"
-        );
+    if (chaz_HeadCheck_check_header("sys/mman.h")) {
+        chaz_ModHand_append_conf("#define CHY_HAS_SYS_MMAN_H\n\n");
     }
 }
 
@@ -173,7 +171,7 @@ die(char* format, ...)
     exit(1);
 }
 
-/* Copyright 2006-2007 Marvin Humphrey
+/* Copyright 2006-2009 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
