@@ -1,16 +1,4 @@
-use strict;
-use warnings;
-
-package KinoSearch::Util::StringHelper;
-use base qw( Exporter );
-
-our @EXPORT_OK = qw(
-    utf8_flag_on
-    utf8_flag_off
-    to_base36
-    from_base36
-    utf8ify
-);
+use KinoSearch;
 
 1;
 
@@ -50,9 +38,9 @@ to_base36(num)
     chy_u32_t num;
 CODE:
 {
-    kino_ByteBuf *bb = kino_StrHelp_to_base36(num);
-    RETVAL = bb_to_sv(bb);
-    REFCOUNT_DEC(bb);
+    kino_CharBuf *buf = kino_StrHelp_to_base36(num);
+    RETVAL = XSBind_cb_to_sv(buf);
+    KINO_DECREF(buf);
 }
 OUTPUT: RETVAL
 
@@ -75,26 +63,41 @@ utf8ify(sv)
 PPCODE:
     sv_utf8_upgrade(sv);
 
+chy_bool_t
+utf8_valid(sv)
+    SV *sv;
+CODE:
+{
+    STRLEN len;
+    char *ptr = SvPV(sv, len);
+    RETVAL = kino_StrHelp_utf8_valid(ptr, len);
+}
+OUTPUT: RETVAL
 
-__POD__
+=for comment
 
-=begin devdocs
+Concatenate one scalar onto the end of the other, ignoring UTF-8 status of the
+second scalar.  This is necessary because $not_utf8 . $utf8 results in a
+scalar which has been infected by the UTF-8 flag of the second argument.
 
-=head1 PRIVATE CLASS
-
-KinoSearch::Util::StringHelper - String related utilities.
-
-=head1 DESCRIPTION
-
-String related utilities, e.g. string comparison functions.
-
-=head1 COPYRIGHT
-
-Copyright 2005-2007 Marvin Humphrey
-
-=head1 LICENSE, DISCLAIMER, BUGS etc.
-
-See L<KinoSearch> version 0.20.
-
-=end devdocs
 =cut
+
+void
+cat_bytes(sv, catted)
+    SV *sv;
+    SV *catted;
+PPCODE:
+{
+    STRLEN len;
+    char *ptr = SvPV(catted, len);
+    if (SvUTF8(sv)) { KINO_THROW("Can't cat_bytes onto a UTF-8 SV"); }
+    sv_catpvn(sv, ptr, len);
+}
+
+__COPYRIGHT__
+
+Copyright 2005-2009 Marvin Humphrey
+
+This program is free software; you can redistribute it and/or modify
+under the same terms as Perl itself.
+
